@@ -1,4 +1,4 @@
-/* dir.c   by Michael Thorpe   2002-12-27 */
+/* dir.c   by Michael Thorpe   2003-08-02 */
 
 #include <errno.h>
 #include <fcntl.h>
@@ -139,11 +139,8 @@ static int dolist_cb(conn *c) {
          goto done;
       if(c->dostat) {
          s=dostat(c,c->glob.gl_pathv[c->globpos]);
-         if(!s) {
-/* FIXME: This looks wrong... */
-/*          putline(c,426,0); */
+         if(!s)
             goto fail;
-         }
          if(dwriterec(c,s,strlen(s))) {
             free(s);
             goto fail;
@@ -205,11 +202,8 @@ static int dolist_cb(conn *c) {
          goto done;
       if(c->dostat) {
          s=dostat(c,de->d_name);
-         if(!s) {
-/* FIXME: This looks wrong... */
-/*          putline(c,426,0); */
+         if(!s)
             goto fail;
-         }
          if(dwriterec(c,s,strlen(s))) {
             free(s);
             goto fail;
