@@ -1,17 +1,19 @@
-/* main.c   by Michael Thorpe   2002-10-20 */
+/* main.c   by Michael Thorpe   2002-12-27 */
 
 #include <errno.h>
+#include <fcntl.h>
 #include <signal.h>
-#include <stdlib.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <fcntl.h>
+#include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/wait.h>
-#include <sys/stat.h>
 #include "ftpd.h"
 
+static char *pid_file=PID_FILE;
+
 static void reaper(int sig) {
    while(0<wait3(0,WNOHANG,0))
       ;
@@ -20,7 +22,6 @@ static void reaper(int sig) {
 #endif
 }
 
-#ifdef PID_FILE
 int writepid(char *file,pid_t pid) {
    int f;
    char s[12];
@@ -51,7 +52,6 @@ void pleasedie(int sig) {
    while(baselistener)
       dellistener(baselistener->addr,baselistener->cport);
 }
-#endif
 
 int main(int argc,char **argv) {
 /* This whole function should be redone and improved */
@@ -83,23 +83,20 @@ int main(int argc,char **argv) {
    close(2);
 #endif
    pid=curpid=getpid();
-#ifdef PID_FILE
-   if(writepid(PID_FILE,pid))
+   if(pid_file && writepid(pid_file,pid))
       pid=0;
    signal(SIGINT,pleasedie);
    signal(SIGTERM,pleasedie);
-#endif
    log(0,LOG_NOTICE,"Starting");
    signal(SIGCHLD,reaper);
    signal(SIGPIPE,SIG_IGN);
    signal(SIGHUP,reopenlog);
+   close(2);
    chdir("/");
    doloop();
    log(0,LOG_NOTICE,"Exiting");
-#ifdef PID_FILE
-   if(pid==curpid)
-      unlink(PID_FILE);
-#endif
+   if(pid_file && pid==curpid)
+      unlink(pid_file);
    return(0);
 }
 
